==> multipaper-api-1.18.2-R0.1-20220416.111638-1-sources.jar: org/bukkit/entity/Raider.java <==
package org.bukkit.entity;

import org.bukkit.block.Block;
import org.jetbrains.annotations.Nullable;

public interface Raider extends Monster {

    /**
     * Gets the block the raider is targeting to patrol.
     *
     * @return target block or null
     */
    @Nullable
    Block getPatrolTarget();

    /**
     * Sets the block the raider is targeting to patrol.
     *
     * @param block target block or null. Must be in same world as the entity
     */
    void setPatrolTarget(@Nullable Block block);

    /**
     * Gets whether this entity is a patrol leader.
     *
     * @return patrol leader status
     */
    boolean isPatrolLeader();

    /**
     * Sets whether this entity is a patrol leader.
     *
     * @param leader patrol leader status
     */
    void setPatrolLeader(boolean leader);

    /**
     * Gets whether this mob can join an active raid.
     *
     * @return CanJoinRaid status
     */
    boolean isCanJoinRaid();

    /**
     * Sets whether this mob can join an active raid.
     *
     * @param join CanJoinRaid status
     */
    void setCanJoinRaid(boolean join);

    // Paper start
    /**
     * Returns whether the raider is celebrating a raid victory.
     *
     * @return whether the raider is celebrating a raid victory
     */
    boolean isCelebrating();

    /**
     * Sets whether the raider is celebrating a raid victory.
     *
     * @param celebrating whether the raider is celebrating a raid victory
     */
    void setCelebrating(boolean celebrating);
    // Paper end
}

==> multipaper-api-1.19.3-R0.1-20230209.150747-1-sources.jar: org/bukkit/entity/Raider.java <==
package org.bukkit.entity;

import org.bukkit.Sound;
import org.bukkit.block.Block;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public interface Raider extends Monster {

    /**
     * Gets the block the raider is targeting to patrol.
     *
     * @return target block or null
     */
    @Nullable
    Block getPatrolTarget();

    /**
     * Sets the block the raider is targeting to patrol.
     *
     * @param block target block or null. Must be in same world as the entity
     */
    void setPatrolTarget(@Nullable Block block);

    /**
     * Gets whether this entity is a patrol leader.
     *
     * @return patrol leader status
     */
    boolean isPatrolLeader();

    /**
     * Sets whether this entity is a patrol leader.
     *
     * @param leader patrol leader status
     */
    void setPatrolLeader(boolean leader);

    /**
     * Gets whether this mob can join an active raid.
     *
     * @return CanJoinRaid status
     */
    boolean isCanJoinRaid();

    /**
     * Sets whether this mob can join an active raid.
     *
     * @param join CanJoinRaid status
     */
    void setCanJoinRaid(boolean join);

    /**
     * Get the {@link Sound} this entity will play when celebrating.
     *
     * @return the celebration sound
     */
    @NotNull
    Sound getCelebrationSound();

    // Paper start
    /**
     * Returns whether the raider is celebrating a raid victory.
     *
     * @return whether the raider is celebrating a raid victory
     */
    boolean isCelebrating();

    /**
     * Sets whether the raider is celebrating a raid victory.
     *
     * @param celebrating whether the raider is celebrating a raid victory
     */
    void setCelebrating(boolean celebrating);
    // Paper end
}
